==> nextcloud-27.1.1p0.tgz: nextcloud/apps/activity/l10n/eu.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Kopiatuta!",
    "Not supported!" : "Ez da onartzen!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "{name} (invisible)" : "{name} (ikusezina)",
    "{name} (restricted)" : "{name} (mugatua)",
    "Home" : "Etxea",
    "in {path}" : "hemen {path}",
    "This stream will show events like additions, changes & shares" : "Korronte honek gehiketak, aldaketak eta partekatzeak bezalako gertaerak erakusten ditu",
    "There are no events for this filter" : "Ez dago gertaerarik iragazki honetarako",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "Open {filename}" : "Ireki {filename}",
    "Activity" : "Jarduerak",
    "Personal activity feed for %s" : "%s-(r)en jarduera jario pertsonala",
    "Your feed URL is invalid" : "Zure jarioaren URLa baliogabea da",
    "Your settings have been updated." : "Zure ezarpenak ondo eguneratu dira.",
    "Settings have been updated." : "Ezarpenak eguneratu dira.",
    "Recent activity" : "Azken jarduerak",
    "No activities" : "Ez da jarduerarik",
    "More activities" : "Jarduera gehiago",
    "Daily activity summary for %s" : "%s-(r)en eguneko jardueren laburpena",
    "_and %n more _::_and %n more _" : ["eta %n gehiago","eta %n gehiago"],
    "All activities" : "Jarduera guztiak",
    "By others" : "Besteenak",
    "By you" : "Zureak",
    "Activity at %s" : "Jarduera %s -n",
    "Hello %s" : "Kaixo %s",
    "Hello %s," : "Kaixo %s,",
    "There was some activity at %s" : "%s-(e)n jarduera egon da",
    "Mail" : "Epostaz",
    "Push" : "Push",
    "Notifications" : "Jakinarazpenak",
    "This application enables people to view a log of activities about them, their files or other data." : "Aplikazio honek jendeari aukera ematen dio fitxategiei edo bestelako datuei buruzko jardueren erregistroa ikusteko.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Aplikazio honek, jendeari aukera ematen dio Nextclouden bere fitxategiekin eta datuekin erlazionatutako ekintzak ikusteko.\n\t\tPertsona bakoitzak bere jarduera-ezarpenak konfigura ditzake ezarpen pertsonaletan,\n\t\tmugikorretara zein jarduera eraman behar den aukeratzeko, posta elektroniko bidez bidalita\n\t\tedo goizero egunero laburpen bat bidaltzen den.\n\t\tInformazio gehiago Jardueren dokumentazioan dago eskuragarri.",
    "Activity notification configuration" : "Jardueren jakinarazpenen konfigurazioa",
    "Send email" : "Bidali posta-mezua",
    "Send push notification" : "Bidali push jakinarazpena",
    "You need to set up your email address before you can receive notification emails." : "Zure helbide elektronikoa konfiguratu behar duzu jakinarazpenak postaz jasotzeko.",
    "Send activity emails" : "Jardueren mezu elektronikoak bidali",
    "As soon as possible" : "Ahal bezain laster",
    "Hourly" : "Orduro",
    "Daily" : "Egunero",
    "Weekly" : "Astero",
    "No activity yet" : "Oraindik ez dago jarduerarik",
    "Unable to load the activity list" : "Ezin izan da jarduera-zerrenda kargatu",
    "Notification" : "Jakinarazpena",
    "Enable notification emails" : "Gaitu jakinarazpen emailak",
    "Choose for which activities you want to get an email or push notification." : "Aukeratu zein jardueratarako jaso nahi duzun posta elektronikoa edo push jakinarazpena.",
    "Choose for which activities you want to get a push notification." : "Aukeratu zein jardueratarako jaso nahi duzun push jakinarazpena.",
    "Daily activity summary" : "Jardueren eguneroko laburpena",
    "Send daily activity summary in the morning" : "Bidali goizez eguneroko jardueraren laburpena",
    "Default settings" : "Lehenetsitako ezarpenak",
    "Configure the default notification settings for new accounts." : "Konfiguratu jakinarazpen-ezarpen lehenetsiak kontu berrietarako.",
    "Unable to save the settings" : "Ezin izan dira ezarpenak gorde",
    "Activity feed" : "Jardueren jarioa",
    "Activity settings" : "Jardueraren ezarpenak",
    "Enable RSS feed" : "Gaitu RSS jarioa",
    "RSS feed" : "RSS jarioa",
    "Copy RSS feed link" : "Kopiatu RSS jario esteka",
    "Personal notification settings" : "Jakinarazpen pertsonalen ezarpenak",
    "No more events to load" : "Ez dago kargatzeko gertaera gehiagorik",
    "This application enables users to view a log of activities about them or about files." : "Aplikazio honek aukera ematen die erabiltzaileei beraiei edo fitxategiei buruzko jardueren erregistroa ikusteko.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Aplikazio honek aukera ematen die erabiltzaileei Nextclouden dauzkaten fitxategietan egindako ekintzak ikusteko.\n\t\tGaituz gero, erabiltzaileek \"Jarduera\" ikono berri bat ikusiko dute aplikazioen menuan.\n\t\tKlik egiterakoan, orri berri bat agertuko zaie beraien fitxategietan egindako aldaketa guztien jarraipena egin dezaten – fitxategi sortu berriak, ezabaketak, leku-aldatzeak, berrizendatzeak, eguneratzeak eta partekatzeak.\n\t\tErabiltzaileek haien jarduera ezarpenak konfiguratu ditzakete menu pertsonalean.\n\t\tHonek, gordeko den jarduera mota zehaztuko du, eta baita ere erabiltzaileak nola ikusiko dituen jarduera propioak:\n\t\tsarean bakarrik egongo diren eskuragarri, eta ea tarteka posta elektronikoz laburpen mezu bat jaso nahiko duen.\n\t\tInformazio gehiago dago eskuragarri Jarduerak (Activity) aplikazioaren dokumentazio biltegian.",
    "Activities" : "Jarduerak",
    "Configure the default notification settings for new users." : "Konfiguratu jakinarazpenen ezarpen lehenetsiak erabiltzaile berrientzat."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.5.tgz: nextcloud/apps/activity/l10n/eu.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s-(r)en jarduera jario pertsonala",
    "Your feed URL is invalid" : "Zure jarioaren URLa baliogabea da",
    "Activity feed for %1$s" : "%1$s-ren jarduera jarioa",
    "Activity feed" : "Jardueren jarioa",
    "Your settings have been updated." : "Zure ezarpenak ondo eguneratu dira.",
    "Settings have been updated." : "Ezarpenak eguneratu dira.",
    "Recent activity" : "Azken jarduerak",
    "No activities" : "Ez da jarduerarik",
    "More activities" : "Jarduera gehiago",
    "Daily activity summary for %s" : "%s-(r)en eguneko jardueren laburpena",
    "_and %n more _::_and %n more _" : ["eta %n gehiago","eta %n gehiago"],
    "All activities" : "Jarduera guztiak",
    "By others" : "Besteenak",
    "By you" : "Zureak",
    "Activity at %s" : "Jarduera %s -n",
    "Hello %s" : "Kaixo %s",
    "Hello %s," : "Kaixo %s,",
    "There was some activity at %s" : "%s-(e)n jarduera egon da",
    "Mail" : "Epostaz",
    "Push" : "Push",
    "Activity" : "Jarduerak",
    "Notifications" : "Jakinarazpenak",
    "This application enables people to view a log of activities about them, their files or other data." : "Aplikazio honek jendeari aukera ematen dio fitxategiei edo bestelako datuei buruzko jardueren erregistroa ikusteko.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Aplikazio honek, jendeari aukera ematen dio Nextclouden bere fitxategiekin eta datuekin erlazionatutako ekintzak ikusteko.\n\t\tPertsona bakoitzak bere jarduera-ezarpenak konfigura ditzake ezarpen pertsonaletan,\n\t\tmugikorretara zein jarduera eraman behar den aukeratzeko, posta elektroniko bidez bidalita\n\t\tedo goizero egunero laburpen bat bidaltzen den.\n\t\tInformazio gehiago Jardueren dokumentazioan dago eskuragarri.",
    "Activity notification configuration" : "Jardueren jakinarazpenen konfigurazioa",
    "Send email" : "Bidali posta-mezua",
    "Send push notification" : "Bidali push jakinarazpena",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "You need to set up your email address before you can receive notification emails." : "Zure helbide elektronikoa konfiguratu behar duzu jakinarazpenak postaz jasotzeko.",
    "Send activity emails" : "Jardueren mezu elektronikoak bidali",
    "As soon as possible" : "Ahal bezain laster",
    "Hourly" : "Orduro",
    "Daily" : "Egunero",
    "Weekly" : "Astero",
    "You commented" : "Iruzkindu duzu",
    "Message deleted by author" : "Egileak mezua ezabatu du",
    "Open {filename}" : "Ireki {filename}",
    "in {path}" : "hemen {path}",
    "Home" : "Etxea",
    "Your activities" : "Zure jarduerak",
    "Loading activities" : "Jarduerak kargatzen",
    "This stream will show events like additions, changes & shares" : "Korronte honek gehiketak, aldaketak eta partekatzeak bezalako gertaerak erakusten ditu",
    "No activity yet" : "Oraindik ez dago jarduerarik",
    "Loading more activities" : "Jarduera gehiago kargatzen",
    "No more activities." : "Ez dago jarduera gehiago.",
    "Could not load activities" : "Ezin izan dira jarduerak kargatu",
    "Activity settings" : "Jardueraren ezarpenak",
    "Enable RSS feed" : "Gaitu RSS jarioa",
    "RSS feed" : "RSS jarioa",
    "Copy RSS feed link" : "Kopiatu RSS jario esteka",
    "Personal notification settings" : "Jakinarazpen pertsonalen ezarpenak",
    "Could not enable RSS link" : "Ezin izan da RSS esteka aktibatu",
    "RSS link copied to clipboard" : "RSS esteka arbelean kopiatu da",
    "Could not copy the RSS link, please copy manually:" : "Ezin izan da RSS esteka kopiatu, mesedez kopiatu eskuz:",
    "Unable to load the activity list" : "Ezin izan da jarduera-zerrenda kargatu",
    "Notification" : "Jakinarazpena",
    "Enable notification emails" : "Gaitu jakinarazpen emailak",
    "Choose for which activities you want to get an email or push notification." : "Aukeratu zein jardueratarako jaso nahi duzun posta elektronikoa edo push jakinarazpena.",
    "Choose for which activities you want to get a push notification." : "Aukeratu zein jardueratarako jaso nahi duzun push jakinarazpena.",
    "Daily activity summary" : "Jardueren eguneroko laburpena",
    "Send daily activity summary in the morning" : "Bidali goizez eguneroko jardueraren laburpena",
    "Default settings" : "Lehenetsitako ezarpenak",
    "Configure the default notification settings for new accounts." : "Konfiguratu jakinarazpen-ezarpen lehenetsiak kontu berrietarako.",
    "Unable to save the settings" : "Ezin izan dira ezarpenak gorde",
    "No more events to load" : "Ez dago kargatzeko gertaera gehiagorik",
    "Copied!" : "Kopiatuta!",
    "Not supported!" : "Ez da onartzen!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "{name} (invisible)" : "{name} (ikusezina)",
    "{name} (restricted)" : "{name} (mugatua)",
    "There are no events for this filter" : "Ez dago gertaerarik iragazki honetarako",
    "Activities" : "Jarduerak",
    "Could not load activites" : "Ezin izan dira jarduerak kargatu"
},
"nplurals=2; plural=(n != 1);");
